/**
 * plugin.min.js
 *
 */

tinymce.PluginManager.add('filehub', function(editor) {
	function filehub_onMessage(event){
		if(event.data.sender === 'filehub'){
			tinymce.activeEditor.insertContent(event.data.html);
			tinymce.activeEditor.windowManager.close();

			// Remove event listener for a message from filehub
			if(window.removeEventListener){
				window.removeEventListener('message', filehub_onMessage, false);
			} else {
				window.detachEvent('onmessage', filehub_onMessage);
			}
		}
	}

	if(window.addEventListener){
		window.addEventListener('message', filehub_onMessage, false);
	} else {
		window.attachEvent('onmessage', filehub_onMessage);
	}

	function openmanager() {

		var width = window.innerWidth-20;
		var height = window.innerHeight-40;
		if(width > 1800) width=1800;
		if(height > 1200) height=1200;
		if(width>600){
			var width_reduce = (width - 20) % 138;
			width = width - width_reduce + 10;
		}

		editor.focus(true);
		var title="File Manager";
		if ( editor.getParam("filemanager_title") ) {
			title=editor.getParam("filemanager_title");
		}
		var sort_by="";
		if (editor.getParam("filemanager_sort_by")) {
			sort_by="&sort_by=" + editor.getParam("filemanager_sort_by");
		}
		var descending="false";
		if (editor.getParam("filemanager_descending")) {
			descending=editor.getParam("filemanager_descending");
		}

		const fileUrl = editor.getParam("external_filemanager_path") + '?multiple=true&type=image&sortorder='+descending+sort_by;

		if (tinymce.majorVersion < 5) {
			win = editor.windowManager.open({
				title: title,
				file: fileUrl,
				width: width,
				height: height,
				inline: 1,
				resizable: true,
				maximizable: true
			});
		} else {
			win = editor.windowManager.openUrl({
				title: title,
				url: fileUrl,
				width: width,
				height: height,
				inline: 1,
				resizable: true,
				maximizable: true
			});
		}
	}

	if (tinymce.majorVersion < 5) {
		editor.addButton('filehub', {
			icon: 'browse',
			tooltip: 'Insert file',
			shortcut: 'Ctrl+E',
			onClick: openmanager
		});

		editor.addShortcut('Ctrl+E', '', openmanager);

		editor.addMenuItem('filehub', {
			icon: 'browse',
			text: 'Insert file',
			shortcut: 'Ctrl+E',
			onClick: openmanager,
			context: 'insert'
		});
	} else {
		editor.ui.registry.addButton('filehub', {
			icon: 'browse',
			tooltip: 'Insert file',
			shortcut: 'Ctrl+E',
			onAction: openmanager
		});

		editor.addShortcut('Ctrl+E', '', openmanager);

		editor.ui.registry.addMenuItem('filehub', {
			icon: 'browse',
			text: 'Insert file',
			shortcut: 'Ctrl+E',
			onAction: openmanager,
			context: 'insert'
		});
	}

	return {
		getMetadata: () => ({
		  	name: 'File Manager',
		  	url: 'https://sureshchand.com.np/filehub/docs/'
		})
	  }
});
